[![Documentation Status](https://readthedocs.org/projects/noctiluca/badge/?version=latest)](https://noctiluca.readthedocs.io/en/latest/?badge=latest)

A library for trajectory analysis predominantly from single particle tracking (SPT) experiments. Under construction.

Documentation is hosted at [ReadTheDocs](https://noctiluca.readthedocs.org/en/latest)
